@@ -65,3 +65,9 @@ utils::globalVariables(
     "sum_component", "time_interval"
   )
 )
+
+# quiet R-CMD-check NOTEs that prodlim is unused
+# (parsnip uses it for all censored regression models 
+# but only has it in Suggests)
+#' @importFrom prodlim prodlim
+NULL
