@@ -175,81 +175,6 @@ test_that("survfit_summary_typestable() works for survival prob - stratified (co
   expect_equal(dim(prob), c(length(pred_time), 1))
 })
 
-test_that("survfit_summary_patch_infinite_time() works (coxph)", {
-  lung_pred <- tidyr::drop_na(lung)
-  pred_time <- c(-Inf, 0, Inf, 1022, -Inf)
-
-  mod <- coxph(Surv(time, status) ~ ., data = lung)
-  surv_fit <- survfit(mod, newdata = lung_pred)
-  surv_fit_summary <- summary(surv_fit, times = pred_time, extend = TRUE)
-
-  surv_fit_summary_patched <- surv_fit_summary %>%
-    survfit_summary_typestable() %>%
-    survfit_summary_patch_infinite_time(eval_time = pred_time)
-
-  prob <- surv_fit_summary_patched$surv
-  exp_prob <- surv_fit_summary$surv
-
-  expect_equal(prob[c(3, 4), ], exp_prob)
-  expect_equal(
-    prob[c(1, 2), ],
-    matrix(1, nrow = 2, ncol = nrow(lung_pred)),
-    ignore_attr = "dimnames"
-  )
-  expect_equal(unname(prob[5, ]), rep(0, nrow(lung_pred)))
-})
-
-test_that("survfit_summary_patch_infinite_time() works (coxnet)", {
-  skip_if_not_installed("glmnet")
-
-  pred_time <- c(-Inf, 0, Inf, 1022, -Inf)
-
-  lung2 <- lung[-14, ]
-  lung_x <- as.matrix(lung2[, c("age", "ph.ecog")])
-  lung_y <- Surv(lung2$time, lung2$status)
-  lung_pred <- lung_x[1:5, ]
-
-  mod <- suppressWarnings(
-    glmnet::glmnet(x = lung_x, y = lung_y, family = "cox")
-  )
-  surv_fit <- survfit(mod, newx = lung_pred, s = 0.1, x = lung_x, y = lung_y)
-  surv_fit_summary <- summary(surv_fit, times = pred_time, extend = TRUE)
-
-  surv_fit_summary_patched <- surv_fit_summary %>%
-    survfit_summary_typestable() %>%
-    survfit_summary_patch_infinite_time(eval_time = pred_time)
-
-  prob <- surv_fit_summary_patched$surv
-  exp_prob <- surv_fit_summary$surv
-
-  expect_equal(prob[c(3, 4), ], exp_prob)
-  expect_equal(
-    prob[c(1, 2), ],
-    matrix(1, nrow = 2, ncol = nrow(lung_pred)),
-    ignore_attr = "dimnames"
-  )
-  expect_equal(unname(prob[5, ]), rep(0, nrow(lung_pred)))
-})
-
-test_that("survfit_summary_restore_time_order() works", {
-  lung_pred <- tidyr::drop_na(lung)
-  pred_time <- c(300, 100, 200)
-
-  mod <- coxph(Surv(time, status) ~ ., data = lung)
-  surv_fit <- survfit(mod, newdata = lung_pred)
-  surv_fit_summary <- summary(surv_fit, times = pred_time, extend = TRUE)
-
-  surv_fit_summary_patched <- surv_fit_summary %>%
-    survfit_summary_typestable() %>%
-    survfit_summary_patch_infinite_time(eval_time = pred_time) %>%
-    survfit_summary_restore_time_order(eval_time = pred_time)
-
-  prob <- surv_fit_summary_patched$surv
-  exp_prob <- surv_fit_summary$surv
-
-  expect_equal(prob, exp_prob[c(3, 1:2), ])
-})
-
 test_that("survfit_summary_patch_missings() works", {
   pred_time <- c(100, 200)
   mod <- coxph(Surv(time, status) ~ age + ph.ecog, data = lung)
