@@ -361,17 +361,7 @@ test_that("survival_prob_coxph() works", {
   expect_true(all(is.na(prob_na$.pred_survival)))
   # for non-missings, get probs right
   expect_equal(prob_non_na$.eval_time, pred_time)
-  expect_equal(
-    prob_non_na$.pred_survival[c(1, 4)],
-    c(1, 0)
-  )
-  expect_equal(
-    prob_non_na %>%
-      dplyr::filter(is.finite(.eval_time)) %>%
-      dplyr::arrange(.eval_time) %>%
-      dplyr::pull(.pred_survival),
-    exp_prob_non_na
-  )
+  expect_equal(prob_non_na$.pred_survival, exp_prob_non_na)
 
   # single observation
   lung_pred <- lung[13, ]
@@ -382,17 +372,7 @@ test_that("survival_prob_coxph() works", {
   prob <- tidyr::unnest(prob, cols = .pred)
   exp_prob <- surv_fit_summary$surv
 
-  expect_equal(
-    prob$.pred_survival[c(1, 4)],
-    c(1, 0)
-  )
-  expect_equal(
-    prob %>%
-      dplyr::filter(is.finite(.eval_time)) %>%
-      dplyr::arrange(.eval_time) %>%
-      dplyr::pull(.pred_survival),
-    exp_prob
-  )
+  expect_equal(prob$.pred_survival, exp_prob)
 
   # all observations with missings
   lung_pred <- lung[c(14, 14), ]
@@ -428,25 +408,13 @@ test_that("survival_prob_coxph() works with confidence intervals", {
   expect_true(all(is.na(pred_na$.pred_lower)))
   expect_true(all(is.na(pred_na$.pred_upper)))
   # for non-missings, get interval right
-  expect_equal(
-    pred_non_na$.pred_lower[c(1, 4)],
-    rep(NA_real_, 2)
-  )
-  expect_equal(
-    pred_non_na$.pred_upper[c(1, 4)],
-    rep(NA_real_, 2)
-  )
   expect_equal(
     pred_non_na %>%
-      dplyr::filter(is.finite(.eval_time)) %>%
-      dplyr::arrange(.eval_time) %>%
       dplyr::pull(.pred_lower),
     exp_pred$lower[, 2] # observation in row 15
   )
   expect_equal(
     pred_non_na %>%
-      dplyr::filter(is.finite(.eval_time)) %>%
-      dplyr::arrange(.eval_time) %>%
       dplyr::pull(.pred_upper),
     exp_pred$upper[, 2] # observation in row 15
   )
